Skip to contents

This function extracts all detected proteins in a glyexp::experiment() or a glystats result. It can be readily passed to the universe parameter of all glyfun functions.

Usage

detected_universe(x)

Arguments

x

A glyexp::experiment() or a glystats result.

Value

A character vector of protein UniProt IDs.

Examples

library(glyexp)
universe <- detected_universe(real_experiment)
length(universe)
#> [1] 4262
universe[1:5]
#> [1] "P08185" "P04196" "P04196" "P04196" "P10909"