Helper function to prepare the universe parameter
detected_universe.RdThis function extracts all detected proteins in a glyexp::experiment() or a glystats result.
It can be readily passed to the universe parameter of all glyfun functions.
Arguments
- x
A
glyexp::experiment()or aglystatsresult.